import { WritableComputedRef } from 'vue-demi';
import { useRoute, useRouter } from 'vue-router';
import { Ref } from 'vue-demi';

interface RouteHashOptions {
    /**
     * Mode to update the router query
     *
     * @default 'replace'
     */
    mode?: 'replace' | 'push';
    /**
     * Route instance, use `useRoute()` if not given
     */
    route?: ReturnType<typeof useRoute>;
    /**
     * Router instance, use `useRouter()` if not given
     */
    router?: ReturnType<typeof useRouter>;
}
declare function useRouteHash(defaultValue?: string, { mode, route, router, }?: RouteHashOptions): WritableComputedRef<string>;

interface RouteQueryOptions {
    /**
     * Mode to update the router query
     *
     * @default 'replace'
     */
    mode?: 'replace' | 'push';
    /**
     * Route instance, use `useRoute()` if not given
     */
    route?: ReturnType<typeof useRoute>;
    /**
     * Router instance, use `useRouter()` if not given
     */
    router?: ReturnType<typeof useRouter>;
}
declare function useRouteQuery(name: string): Ref<null | string | string[]>;
declare function useRouteQuery<T extends null | string | string[] = null | string | string[]>(name: string, defaultValue?: T, options?: RouteQueryOptions): Ref<T>;

export { RouteHashOptions, RouteQueryOptions, useRouteHash, useRouteQuery };
